@@ -7,7 +7,7 @@
  *  Notes     : Simple stopwatch routines for timing code using timeb
  *	             or gettimeofday structs
  *
- * Copyright (c) 1993-2020 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1993-2021 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -52,27 +52,28 @@ char tmp_tb[LEN];
 struct timeb beg_tb;
 struct timeb end_tb;
 
-#			define LSECS 700000000
+#			define LSECS 700000000	/* offset to keep numbers smaller (1992-03-07 20:26:40 UTC) */
 
 #			define BegStopWatch(msg)	{strcpy (msg_tb, msg); ftime (&beg_tb);}
 
 #			define EndStopWatch()		{ftime (&end_tb);}
 
-#			define PrintStopWatch()	{sprintf (tmp_tb, "%s: Beg=[%ld.%d] End=[%ld.%d] Elapsed=[%ld]", \
+#			define PrintStopWatch()	{sprintf (tmp_tb, "%s: Beg=[%ld.%d] End=[%ld.%d] Elap=[%ld ms]", \
 				 msg_tb, beg_tb.time, beg_tb.millitm, \
 				 end_tb.time, end_tb.millitm, \
 				 (((end_tb.time - LSECS) * 1000) + end_tb.millitm) - \
 				 (((beg_tb.time - LSECS) * 1000) + beg_tb.millitm)); \
-				 error_message(2, tmp_tb, "");}
+				 error_message(2, tmp_tb);}
 
 #		else	/* HAVE_SYS_TIMEB_H && HAVE_FTIME */
 
 #		ifdef	HAVE_SYS_TIME_H
 #			include <sys/time.h>
 
-char msg_tb[LEN], tmp_tb[LEN];
-struct timeval beg_tb, end_tb;
+char msg_tb[LEN];
+char tmp_tb[LEN];
 float d_time;
+struct timeval beg_tb, end_tb;
 
 #			define BegStopWatch(msg)	{strcpy (msg_tb, msg); \
 				 (void) gettimeofday (&beg_tb, NULL);}
@@ -83,10 +84,10 @@ float d_time;
 					end_tb.tv_usec += 1000000; \
 				 } \
 				 end_tb.tv_sec -= beg_tb.tv_sec; \
-				 d_time = (end_tb.tv_sec*1000.0 + ((float)end_tb.tv_usec)/1000.0);}
+				 d_time = (end_tb.tv_sec * 1000.0 + ((float) end_tb.tv_usec) / 1000.0);}
 
 #			define PrintStopWatch()	{sprintf (tmp_tb, "StopWatch(%s): %6.3f ms", msg_tb, d_time); \
-				 error_message(2, tmp_tb, "");}
+				 error_message(2, tmp_tb);}
 
 #		endif /* HAVE_SYS_TIME_H */
 #	endif /* HAVE_SYS_TIMEB_H && HAVE_FTIME */
