@@ -3,35 +3,38 @@
  *  Module    : art.c
  *  Author    : I.Lea & R.Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2018-12-18
+ *  Updated   : 2020-07-08
  *  Notes     :
  *
- * Copyright (c) 1991-2019 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -70,7 +73,6 @@ static int date_comp_asc(t_comptype p1, t_comptype p2);
 static int date_comp_desc(t_comptype p1, t_comptype p2);
 static int from_comp_asc(t_comptype p1, t_comptype p2);
 static int from_comp_desc(t_comptype p1, t_comptype p2);
-static int global_get_multiparts(int aindex, MultiPartInfo **malloc_and_setme_info);
 static int global_look_for_multipart_info(int aindex, MultiPartInfo *setme, char start, char stop, int *offset);
 static int last_date_comp_base_asc(t_comptype p1, t_comptype p2);
 static int last_date_comp_base_desc(t_comptype p1, t_comptype p2);
@@ -91,7 +93,7 @@ static t_compfunc eval_sort_arts_func(unsigned int sort_art_type);
 static time_t get_last_posting_date(long n);
 static void sort_base(unsigned int sort_threads_type);
 static void thread_by_multipart(void);
-static void thread_by_percentage(struct t_group *group);
+static void thread_by_percentage(unsigned int percentage);
 static void thread_by_subject(void);
 static void write_overview(struct t_group *group);
 #ifdef NNTP_ABLE
@@ -126,7 +128,8 @@ find_base(
 	grpmenu.max = 0;
 
 #ifdef DEBUG
-	debug_print_arts();
+	if (debug & DEBUG_FILTER)
+		debug_print_arts();
 #endif /* DEBUG */
 
 	for_each_art(i) {
@@ -410,6 +413,10 @@ index_group(
 
 	if (!batch_mode)
 		show_art_msg(group->name);
+	else {
+		if (verbose) /* -> lang.c */
+			wait_message(0, _("Reading %s\n"), group->name);
+	}
 
 	signal_context = cArt;			/* Set this only once curr_group is valid */
 
@@ -814,7 +821,7 @@ read_art_headers(
 		top = arts[top_art].artnum;	/* used if arts are killed */
 		top_art++;
 
-		if (++modified % MODULO_COUNT_NUM == 0)
+		if (++modified % (MODULO_COUNT_NUM * 20) == 0)
 			show_progress(group_msg, modified, total);
 	}
 
@@ -901,12 +908,11 @@ thread_by_subject(
  */
 static void
 thread_by_percentage(
-	struct t_group *group)
+	unsigned int percentage)
 {
 	int i, j, k;
 	int root_num = 0; /* The index number of the root we are currently working on. */
 	unsigned int unmatched; /* This is the number of characters that don't match between the two strings */
-	unsigned int percentage = 100 - group->attribute->thread_perc;
 	size_t slen;
 
 	/* First we need to sort art[] to simplify and speed up the matching. */
@@ -966,9 +972,6 @@ thread_by_percentage(
 
 
 /*
- * This was brought over from tags.c, however this version doesn't
- * operate on base_index
- *
  * Parses a subject header of the type "multipart message subject (01/42)"
  * into a MultiPartInfo struct, or fails if the message subject isn't in the
  * right form.
@@ -998,10 +1001,6 @@ global_get_multipart_info(
 }
 
 
-/*
- * Again this was taken from tags.c, but works on global indices into arts
- * rather than on base_index.
- */
 static int
 global_look_for_multipart_info(
 	int aindex,
@@ -1026,7 +1025,7 @@ global_look_for_multipart_info(
 	if (!pch || !isdigit((int) pch[1]))
 		return 0;
 
-	tmp.base_index = aindex; /* This could be confusing because we are actually storing the index into arts, not the base_index. */
+	tmp.arts_index = aindex;
 	tmp.subject_compare_len = pch - subj;
 	tmp.part_number = (int) strtol(pch + 1, &pch, 10);
 	if (*pch != '/' && *pch != '|')
@@ -1039,6 +1038,12 @@ global_look_for_multipart_info(
 	if (*pch != stop)
 		return 0;
 
+	/*
+	 * skip "blah (00/102)" or "blah (103/102)" subjects
+	 */
+	if (tmp.part_number < 1 || tmp.part_number > tmp.total)
+		return 0;
+
 	tmp.subject = subj;
 	*setme = tmp;
 	*offset = pch - subj;
@@ -1046,28 +1051,53 @@ global_look_for_multipart_info(
 }
 
 
+t_bool
+global_look_for_multipart(
+	int aindex,
+	char start,
+	char stop)
+{
+	char *pch;
+
+	pch = strrchr(arts[aindex].subject, start);
+	if (!pch || !isdigit((int) pch[1]))
+		return FALSE;
+
+	strtol(pch + 1, &pch, 10);
+	if (*pch != '/' && *pch != '|')
+		return FALSE;
+
+	if (!isdigit((int) pch[1]))
+		return FALSE;
+
+	strtol(pch + 1, &pch, 10);
+	if (*pch != stop)
+		return FALSE;
+
+	arts[aindex].multipart_subj = TRUE;
+	return TRUE;
+}
+
+
 /*
- * Taken from tags.c but changed to use indices into arts[] instead of
- * base_index. Changed so that even when we don't have all the parts we
- * return a valid array.
- *
  * Tries to find all the parts to the multipart message pointed to by
- * base_index.
+ * aindex.
  *
- * @return on success, the number of parts found. On failure, zero if not a
- * multipart or the negative value of the first missing part.
- * @param base_index index pointing to one of the messages in a multipart
+ * @return on success, the number of parts found. On failure, zero if not
+ * a multipart or the negative value of the first missing part in case of
+ * tagging.
+ * @param aindex index pointing to one of the messages in a multipart
  * message.
  * @param malloc_and_setme_info on success, set to a malloced array the
  * parts found.
  */
-static int
+int
 global_get_multiparts(
 	int aindex,
-	MultiPartInfo **malloc_and_setme_info)
+	MultiPartInfo **malloc_and_setme_info,
+	t_bool tagging)
 {
-	int i;
-	int part_index;
+	int i, part_index, part_cnt = 0;
 	MultiPartInfo tmp, tmp2;
 	MultiPartInfo *info = NULL;
 
@@ -1089,8 +1119,8 @@ global_get_multiparts(
 	}
 
 	/* try to find all the multiparts... */
-	for_each_art(i) {
-		if (strncmp(arts[i].subject, tmp.subject, tmp.subject_compare_len))
+	for (i = (tagging ? 0 : aindex); i < top_art; i++) {
+		if (!arts[i].multipart_subj || strncmp(arts[i].subject, tmp.subject, tmp.subject_compare_len))
 			continue;
 
 		if (!global_get_multipart_info(i, &tmp2))
@@ -1102,12 +1132,6 @@ global_get_multiparts(
 
 		part_index = tmp2.part_number - 1;
 
-		/*
-		 * skip "blah (00/102)" or "blah (103/102)" subjects
-		 */
-		if (part_index < 0 || part_index >= tmp.total)
-			continue;
-
 		/* repost check: do we already have this part? */
 		if (info[part_index].part_number != -1) {
 			assert(info[part_index].part_number == tmp2.part_number && "bookkeeping error");
@@ -1116,13 +1140,21 @@ global_get_multiparts(
 
 		/* we have a match, hooray! */
 		info[part_index] = tmp2;
+
+		arts[i].multipart_subj = FALSE;
+
+		/* all parts found? */
+		if (++part_cnt == tmp.total)
+			break;
 	}
 
 	/* see if we got them all. */
-	for (i = 0; i < tmp.total; ++i) {
-		if (info[i].part_number != i + 1) {
-			*malloc_and_setme_info = info;
-			return -(i + 1); /* missing part #(i+1) */
+	if (tagging) {
+		for (i = 0; i < tmp.total; ++i) {
+			if (info[i].part_number != i + 1) {
+				free(info);
+				return -(i + 1); /* missing part #(i+1) */
+			}
 		}
 	}
 
@@ -1143,22 +1175,35 @@ thread_by_multipart(
 	MultiPartInfo *minfo = NULL;
 
 	for_each_art(i) {
-		if (IGNORE_ART_THREAD(i) || arts[i].prev >= 0 || !global_get_multiparts(i, &minfo))
+		if (!global_look_for_multipart(i, '[', ']'))
+			global_look_for_multipart(i, '(', ')');
+	}
+
+	for_each_art(i) {
+		if (!arts[i].multipart_subj)
 			continue;
 
+		if (IGNORE_ART_THREAD(i) || arts[i].prev >= 0 || !global_get_multiparts(i, &minfo, FALSE)) {
+			FreeAndNull(minfo);
+			arts[i].multipart_subj = FALSE;
+			continue;
+		}
+
 		threadNum = -1;
 		for (j = minfo[0].total - 1; j >= 0; j--) {
 			if (minfo[j].part_number != -1) {
 				if (threadNum != -1) {
-					arts[minfo[j].base_index].thread = threadNum;
-					arts[threadNum].prev = minfo[j].base_index;
+					arts[minfo[j].arts_index].thread = threadNum;
+					arts[threadNum].prev = minfo[j].arts_index;
 				}
-
-				threadNum = minfo[j].base_index;
+				threadNum = minfo[j].arts_index;
 			}
 		}
+		FreeAndNull(minfo);
+		arts[i].multipart_subj = FALSE;
+		if (i % MODULO_COUNT_NUM == 0) /* TODO: -> lang.c */
+			show_progress(_("Threading by multipart"), i, top_art);
 	}
-	free(minfo);
 }
 
 
@@ -1191,13 +1236,15 @@ make_threads(
 	struct t_group *group,
 	t_bool rethread)
 {
-	if (!cmd_line && !batch_mode)
+	if (!cmd_line && !batch_mode) {
 		info_message((group->attribute->thread_articles == THREAD_NONE ? _(txt_unthreading_arts) : _(txt_threading_arts)));
+		my_flush();
+	}
 
 #ifdef DEBUG
 	if (debug & DEBUG_MISC)
 		error_message(2, "rethread=[%d]  thread_articles=[%d]  attr_thread_articles=[%d]",
-				rethread, tinrc.thread_articles, group->attribute->thread_articles);
+			rethread, tinrc.thread_articles, group->attribute->thread_articles);
 #endif /* DEBUG */
 
 	/*
@@ -1268,7 +1315,7 @@ make_threads(
 			break;
 
 		case THREAD_PERC:
-			thread_by_percentage(group);
+			thread_by_percentage(100 - group->attribute->thread_perc);
 			break;
 
 		default: /* not reached */
@@ -1377,7 +1424,7 @@ parse_headers(
 {
 	char art_from_addr[HEADER_LEN];
 	char art_full_name[HEADER_LEN];
-	char *hdr, *ptr;
+	char *s, *hdr, *ptr;
 	unsigned int lineno = 0;
 	unsigned int max_lineno = 25;
 	t_bool got_from, got_lines, got_received;
@@ -1406,8 +1453,6 @@ parse_headers(
 				 * eg, acorn/faq/part01
 				 */
 				if ((hdr = parse_header(ptr + 1, "rchive-name", FALSE, FALSE, FALSE))) {
-					char *s;
-
 					if ((s = strrchr(hdr, '/')) != NULL) {
 						struct t_archive *archptr = my_malloc(sizeof(struct t_archive));
 
@@ -1489,8 +1534,17 @@ parse_headers(
 
 			case 'S':	/* Subject:  mandatory */
 				if (!h->subject) {
-					if ((hdr = parse_header(ptr + 1, "ubject", FALSE, FALSE, FALSE)))
-						h->subject = hash_str(eat_re(eat_tab(convert_to_printable(rfc1522_decode(hdr), FALSE)), FALSE));
+					if ((hdr = parse_header(ptr + 1, "ubject", FALSE, FALSE, FALSE))) {
+#ifdef HAVE_UNICODE_NORMALIZATION
+						if (IS_LOCAL_CHARSET("UTF-8"))
+							s = normalize(eat_re(convert_to_printable(rfc1522_decode(hdr), FALSE), FALSE));
+						else
+#endif /* HAVE_UNICODE_NORMALIZATION */
+							s = my_strdup(eat_re(convert_to_printable(rfc1522_decode(hdr), FALSE), FALSE));
+
+						h->subject = hash_str(s);
+						free(s);
+					}
 				}
 				break;
 
@@ -1528,7 +1582,8 @@ parse_headers(
 			h->subject = hash_str("<No subject>");
 
 #ifdef DEBUG
-		debug_print_header(h);
+		if (debug & DEBUG_FILTER)
+			debug_print_header(h);
 #endif /* DEBUG */
 		return TRUE;
 	}
@@ -1677,9 +1732,8 @@ build_range_list(
 		res->cnt = res->end - res->start + 1;
 		gap_cnt = 1;
 #	ifdef DEBUG
-		if ((debug & DEBUG_NNTP) && verbose > 1) {
+		if ((debug & DEBUG_NNTP) && verbose > 1)
 			debug_print_file("NNTP", "more then %d ranges after optimization, fetch all at once instead: start: %"T_ARTNUM_PFMT" end: %"T_ARTNUM_PFMT" cnt: %"T_ARTNUM_PFMT"", MAX_CNT, res->start, res->end, res->cnt);
-		}
 #	endif /* DEBUG */
 	}
 	*range_cnt = gap_cnt;
@@ -1762,6 +1816,8 @@ get_path_header(
 	}
 
 	if (fp) {
+		int j = 0;
+
 		prep_msg = fmt_string(_(txt_prep_for_filter_on_path), cur, cnt);
 		while ((buf = tin_fgets(fp, FALSE)) != NULL && buf[0] != '.') {
 #	ifdef DEBUG
@@ -1773,10 +1829,12 @@ get_path_header(
 			artnum = atoartnum(ptr);
 			if ((ptr = tin_strtok(NULL, " ")) == NULL)
 				continue;
-			for_each_art(i) {
+			for (i = j; i < top_art; i++) {
 				if (arts[i].artnum == artnum) {
 					FreeIfNeeded(arts[i].path);
 					arts[i].path = my_strdup(ptr);
+					j = i;
+					break;
 				}
 			}
 			if (++artnum % MODULO_COUNT_NUM == 0)
@@ -1790,11 +1848,11 @@ get_path_header(
 	supported = FALSE;
 	if (nntp_caps.xpat)
 		nntp_caps.xpat = FALSE;
-	/* as nntp_caps.hdr may work with other headers we don't disable it*/
+	/* as nntp_caps.hdr may work with other headers we don't disable it */
 
 #	ifdef DEBUG
 	if ((debug & DEBUG_NNTP) && verbose > 1)
-		debug_print_file("NNTP", "%s: Neither \"[X]HDR Path\" nor \"XPAT Path\" are supportet.", group->name);
+		debug_print_file("NNTP", "%s: Neither \"[X]HDR Path\" nor \"XPAT Path\" are supported.", group->name);
 #	endif /* DEBUG */
 	return supported;
 }
@@ -1991,12 +2049,20 @@ read_overview(
 
 			/* for duplicated headers this is last match counts, INN >= 2.5.3 does first match counts */
 			if (expensive_over_parse) { /* strange order */
-				/* madatory fields */
+				/* mandatory fields */
 				if (ofmt[count].type == OVER_T_STRING) {
 					if (!strcasecmp(ofmt[count].name, "Subject:")) {
-						if (*ptr)
-							art->subject = hash_str(eat_re(eat_tab(convert_to_printable(rfc1522_decode(ptr), FALSE)), FALSE));
-						else {
+						if (*ptr) {
+#ifdef HAVE_UNICODE_NORMALIZATION
+							if (IS_LOCAL_CHARSET("UTF-8"))
+								q =  normalize(eat_re(eat_tab(convert_to_printable(rfc1522_decode(ptr), FALSE)), FALSE));
+							else
+#endif /* HAVE_UNICODE_NORMALIZATION */
+								q = my_strdup(eat_re(eat_tab(convert_to_printable(rfc1522_decode(ptr), FALSE)), FALSE));
+
+							art->subject = hash_str(q);
+							free(q);
+						} else {
 							art->subject = hash_str("");
 #ifdef DEBUG
 							if ((debug & DEBUG_NNTP) && verbose > 1)
@@ -2103,9 +2169,17 @@ read_overview(
 			} else { /* first 7 fields are in RFC 3977 order */
 				switch (count) {
 					case 1: /* Subject: */
-						if (*ptr)
-							art->subject = hash_str(eat_re(eat_tab(convert_to_printable(rfc1522_decode(ptr), FALSE)), FALSE));
-						else {
+						if (*ptr) {
+#ifdef HAVE_UNICODE_NORMALIZATION
+							if (IS_LOCAL_CHARSET("UTF-8"))
+								q =  normalize(eat_re(eat_tab(convert_to_printable(rfc1522_decode(ptr), FALSE)), FALSE));
+							else
+#endif /* HAVE_UNICODE_NORMALIZATION */
+								q = my_strdup(eat_re(eat_tab(convert_to_printable(rfc1522_decode(ptr), FALSE)), FALSE));
+
+							art->subject = hash_str(q);
+							free(q);
+						} else {
 							art->subject = hash_str("");
 #ifdef DEBUG
 							if ((debug & DEBUG_NNTP) && verbose > 1)
@@ -2242,7 +2316,7 @@ read_overview(
 			continue;
 
 		/* we might lose accuracy here, but that shouldn't hurt */
-		if (artnum % MODULO_COUNT_NUM == 0)
+		if (artnum % (MODULO_COUNT_NUM * 20) == 0)
 			show_progress(group_msg, artnum - min, max - min);
 
 		top_art++;				/* Basically this statement commits the article */
@@ -2329,7 +2403,7 @@ read_overview(
 						art->xref = my_strdup(ptr);
 					}
 					/* we might lose accuracy here, but that shouldn't hurt */
-					if (artnum % MODULO_COUNT_NUM == 0)
+					if (artnum % (MODULO_COUNT_NUM * 20) == 0)
 						show_progress(group_msg, artnum - min, max - min);
 				}
 			}
@@ -2461,6 +2535,9 @@ write_overview(
 	}
 #endif /* CHARSET_CONVERSION */
 
+	if (verbose && batch_mode) /* -> lang.c */
+		wait_message(0, _("Writing %s\n"), group->name);
+
 	for_each_art(i) {
 		char *p;
 		char *q, *ref;
@@ -2538,8 +2615,16 @@ write_overview(
 				q = NULL;
 			}
 		}
+		if (i % (MODULO_COUNT_NUM * 20) == 0) /* TODO: -> lang.c */
+			show_progress(_("Writing overview cache..."), i, top_art);
 	}
+#ifdef HAVE_FCHMOD
 	fchmod(fileno(fp), (mode_t) (S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH));
+	/*
+	 * TODO:
+	 * add code for !HAVE_FCHMOD && HAVE_CHMOD
+	 */
+#endif /* HAVE_FCHMOD */
 	fclose(fp);
 }
 
@@ -3115,6 +3200,7 @@ set_article(
 	art->inrange = FALSE;
 	art->matched = FALSE;
 	art->keep_in_base = FALSE;
+	art->multipart_subj = FALSE;
 }
 
 
@@ -3193,10 +3279,10 @@ print_date(
 
 	if ((tm = gmtime(&secs)) != NULL)
 		snprintf(date, sizeof(date), "%02d %.3s %04d %02d:%02d:%02d GMT",
-				tm->tm_mday,
-				months_a[tm->tm_mon],
-				tm->tm_year + 1900,
-				tm->tm_hour, tm->tm_min, tm->tm_sec);
+			tm->tm_mday,
+			months_a[tm->tm_mon],
+			tm->tm_year + 1900,
+			tm->tm_hour, tm->tm_min, tm->tm_sec);
 	else
 		snprintf(date, sizeof(date), "01 Jan 1970 00:00:00 UTC");
 
@@ -3218,9 +3304,8 @@ print_from(
 	if (article->name != NULL) {
 		q = my_strdup(article->name);
 #ifdef CHARSET_CONVERSION
-		if (charset != -1) {
+		if (charset != -1)
 			buffer_to_network(q, charset);
-		}
 #endif /* CHARSET_CONVERSION */
 		p = rfc1522_encode(article->name, tinrc.mm_local_charset, FALSE);
 		unfold_header(p);
@@ -3232,7 +3317,7 @@ print_from(
 		free(p);
 		free(q);
 	} else
-		STRCPY(from, article->from);
+		snprintf(from, sizeof(from), "<%s>", article->from);
 
 	return from;
 }
