@@ -7,7 +7,7 @@
  *  Notes     : Routines to authenticate to a news server via NNTP.
  *              DON'T USE get_respcode() THROUGHOUT THIS CODE.
  *
- * Copyright (c) 1997-2020 Dirk Nimmich <nimmich@muenster.de>
+ * Copyright (c) 1997-2021 Dirk Nimmich <nimmich@muenster.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -101,7 +101,13 @@ read_newsauth_file(
 			error_message(4, _(txt_error_insecure_permissions), filename, statbuf.st_mode);
 			/*
 			 * TODO: fix permissions?
-			 * fchmod(fd, S_IRUSR|S_IWUSR);
+			 * #ifdef HAVE_FCHMOD
+			 *  fchmod(fd, S_IRUSR|S_IWUSR);
+			 * #else
+			 * #	ifdef HAVE_CHMOD
+			 *  chmod(filename, S_IRUSR|S_IWUSR);
+			 * #	endif
+			 * #endif
 			 */
 		}
 #	endif /* !FILE_MODE_BROKEN */
@@ -188,7 +194,7 @@ do_authinfo_user(
 
 	if ((authpass == NULL) || (*authpass == '\0')) {
 #	ifdef DEBUG
-		if ((debug & DEBUG_NNTP) && verbose >1)
+		if ((debug & DEBUG_NNTP) && verbose > 1)
 			debug_print_file("NNTP", "authorization failed: no password");
 #	endif /* DEBUG */
 		error_message(2, _(txt_auth_failed_nopass), server);
@@ -303,7 +309,7 @@ authinfo_plain(
 #	ifdef DEBUG
 		else {
 			if ((debug & DEBUG_NNTP) && verbose > 1)
-				 debug_print_file("NNTP", "read_newsauth_file(\"%s\", \"%s\", \"%s\") failed", server, authuser, authpass);
+				debug_print_file("NNTP", "read_newsauth_file(\"%s\", \"%s\", \"%s\") failed", server, authuser, authpass);
 		}
 #	endif /* DEBUG */
 	}
@@ -550,8 +556,9 @@ sasl_auth_plain(
 		gsasl_done(ctx);
 		return p;
 	}
-	gsasl_property_set(session, GSASL_AUTHID, user);
-	gsasl_property_set(session, GSASL_PASSWORD, pass);
+	/* GSASL_AUTHZID (authorization identity) is (usually) unused with NNTP */
+	gsasl_property_set(session, GSASL_AUTHID, user);	/* authentication identity */
+	gsasl_property_set(session, GSASL_PASSWORD, pass);	/* password of the authentication identity */
 	if (gsasl_step64(session, NULL, &p) != GSASL_OK)
 		FreeAndNull(p);
 	gsasl_finish(session);
