@@ -3,10 +3,10 @@
  *  Module    : debug.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2019-07-23
+ *  Updated   : 2020-05-19
  *  Notes     : debug routines
  *
- * Copyright (c) 1991-2020 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -109,6 +109,8 @@ debug_delete_files(
 	if (debug & (DEBUG_MISC | DEBUG_REMOVE)) {
 		joinpath(file, sizeof(file), TMPDIR, "ACTIVE");
 		unlink(file);
+		joinpath(file, sizeof(file), TMPDIR, "GNKSA");
+		unlink(file);
 	}
 }
 
@@ -122,10 +124,7 @@ debug_print_arts(
 {
 	int i;
 
-	if (!(debug & DEBUG_FILTER))
-		return;
-
-	for_each_art(i)
+	for_each_art(i) /* fopen/close() horror */
 		debug_print_header(&arts[i]);
 }
 
@@ -134,28 +133,29 @@ void
 debug_print_header(
 	struct t_article *s)
 {
+	static char file[PATH_LEN] = { '\0' };
 	FILE *fp;
-	char file[PATH_LEN];
 
 	if (!(debug & DEBUG_FILTER))
 		return;
 
-	joinpath(file, sizeof(file), TMPDIR, "ARTS");
+	if (!*file)
+		joinpath(file, sizeof(file), TMPDIR, "ARTS");
 
 	if ((fp = fopen(file, "a")) != NULL) {
-		fprintf(fp,"art=[%5"T_ARTNUM_PFMT"] tag=[%s] kill=[%s] selected=[%s]\n", s->artnum,
+		fprintf(fp, "art=[%5"T_ARTNUM_PFMT"] tag=[%s] kill=[%s] selected=[%s]\n", s->artnum,
 			bool_unparse(s->tagged),
 			bool_unparse(s->killed),
 			bool_unparse(s->selected));
-		fprintf(fp,"subj=[%-38s]\n", s->subject);
-		fprintf(fp,"date=[%ld]  from=[%s]  name=[%s]\n", (long) s->date, s->from,
+		fprintf(fp, "subj=[%-38s]\n", s->subject);
+		fprintf(fp, "date=[%ld]  from=[%s]  name=[%s]\n", (long) s->date, s->from,
 			BlankIfNull(s->name));
-		fprintf(fp,"msgid=[%s]  refs=[%s]\n",
+		fprintf(fp, "msgid=[%s]  refs=[%s]\n",
 			BlankIfNull(s->msgid),
 			BlankIfNull(s->refs));
 
 		if (s->killed)
-			fprintf(fp,"score=[%d] gnksa=[%d] lines=[%d]\n", s->score, s->gnksa_code, s->line_count);
+			fprintf(fp, "score=[%d] gnksa=[%d] lines=[%d]\n", s->score, s->gnksa_code, s->line_count);
 
 		if (s->archive) {
 			fprintf(fp, "archive.name=[%-38s]  ", s->archive->name);
@@ -164,9 +164,15 @@ debug_print_header(
 			if (s->archive->ispart)
 				fprintf(fp, "archive.ispart=[%s]\n", bool_unparse(s->archive->ispart));
 		}
-		fprintf(fp,"thread=[%d]  prev=[%d]  status=[%u]\n\n", s->thread, s->prev, s->status);
+		fprintf(fp, "thread=[%d]  prev=[%d]  status=[%u]\n\n", s->thread, s->prev, s->status);
 		fflush(fp);
+#ifdef HAVE_FCHMOD
 		fchmod(fileno(fp), (S_IRUGO|S_IWUGO));
+#else
+#	ifdef HAVE_CHMOD
+		chmod(file, (S_IRUGO|S_IWUGO));
+#	endif /* HAVE_CHMOD */
+#endif /* HAVE_FCHMOD */
 		fclose(fp);
 	}
 }
@@ -176,13 +182,14 @@ void
 debug_print_active(
 	void)
 {
+	static char file[PATH_LEN] = { '\0' };
 	FILE *fp;
-	char file[PATH_LEN];
 
 	if (!(debug & DEBUG_MISC))
 		return;
 
-	joinpath(file, sizeof(file), TMPDIR, "ACTIVE");
+	if (!*file)
+		joinpath(file, sizeof(file), TMPDIR, "ACTIVE");
 
 	if ((fp = fopen(file, "w")) != NULL) {
 		int i;
@@ -203,7 +210,13 @@ debug_print_active(
 			if (debug & DEBUG_ATTRIB)
 				debug_print_attributes(group->attribute, fp);
 		}
+#ifdef HAVE_FCHMOD
 		fchmod(fileno(fp), (S_IRUGO|S_IWUGO));
+#else
+#	ifdef HAVE_CHMOD
+		chmod(file, (S_IRUGO|S_IWUGO));
+#	endif /* HAVE_CHMOD */
+#endif /* HAVE_FCHMOD */
 		fclose(fp);
 	}
 }
@@ -248,24 +261,30 @@ debug_print_attributes(
 
 void
 debug_print_malloc(
-	int is_malloc,
+	t_bool is_malloc,
 	const char *xfile,
 	int line,
 	size_t size)
 {
-	FILE *fp;
-	char file[PATH_LEN];
+	static char file[PATH_LEN] = { '\0' };
 	static size_t total = 0;
+	FILE *fp;
 
-	if (debug & DEBUG_MEM) {
+	if (!*file)
 		joinpath(file, sizeof(file), TMPDIR, "MALLOC");
-		if ((fp = fopen(file, "a")) != NULL) {
-			total += size;
-			/* sometimes size_t is long */
-			fprintf(fp, "%12s:%-4d %s(%6lu). Total %lu\n", xfile, line, is_malloc ? " malloc" : "realloc", (unsigned long) size, (unsigned long) total);
-			fchmod(fileno(fp), (S_IRUGO|S_IWUGO));
-			fclose(fp);
-		}
+
+	if ((fp = fopen(file, "a")) != NULL) {
+		total += size;
+		/* sometimes size_t is long */
+		fprintf(fp, "%12s:%-4d %s(%6lu). Total %lu\n", xfile, line, is_malloc ? " malloc" : "realloc", (unsigned long) size, (unsigned long) total);
+#ifdef HAVE_FCHMOD
+		fchmod(fileno(fp), (S_IRUGO|S_IWUGO));
+#else
+#	ifdef HAVE_CHMOD
+		chmod(file, (S_IRUGO|S_IWUGO));
+#	endif /* HAVE_CHMOD */
+#endif /* HAVE_FCHMOD */
+		fclose(fp);
 	}
 }
 
@@ -308,15 +327,13 @@ void
 debug_print_filters(
 	void)
 {
-	FILE *fp;
-	char file[PATH_LEN];
 	int i, num;
+	static char file[PATH_LEN] = { '\0' };
 	struct t_filter *the_filter;
+	FILE *fp;
 
-	if (!(debug & DEBUG_FILTER))
-		return;
-
-	joinpath(file, sizeof(file), TMPDIR, "FILTER");
+	if (!*file)
+		joinpath(file, sizeof(file), TMPDIR, "FILTER");
 
 	if ((fp = fopen(file, "w")) != NULL) {
 		/*
@@ -331,7 +348,13 @@ debug_print_filters(
 		}
 		fprintf(fp, "*** END GLOBAL FILTER ***\n");
 
+#ifdef HAVE_FCHMOD
 		fchmod(fileno(fp), (S_IRUGO|S_IWUGO));
+#else
+#	ifdef HAVE_CHMOD
+		chmod(file, (S_IRUGO|S_IWUGO));
+#	endif /* HAVE_CHMOD */
+#endif /* HAVE_FCHMOD */
 		fclose(fp);
 	}
 }
@@ -358,8 +381,14 @@ debug_print_file(
 	joinpath(file, sizeof(file), TMPDIR, fname);
 
 	if ((fp = fopen(file, "a")) != NULL) {
-		fprintf(fp,"%s\n", buf);
+		fprintf(fp, "%s\n", buf);
+#ifdef HAVE_FCHMOD
 		fchmod(fileno(fp), (S_IRUGO|S_IWUGO));
+#else
+#	ifdef HAVE_CHMOD
+		chmod(file, (S_IRUGO|S_IWUGO));
+#	endif /* HAVE_CHMOD */
+#endif /* HAVE_FCHMOD */
 		fclose(fp);
 	}
 	free(buf);
@@ -407,7 +436,13 @@ debug_print_bitmap(
 					(art->status == ART_READ ? "READ" : "UNREAD"));
 			}
 			debug_print_newsrc(&group->newsrc, fp);
+#ifdef HAVE_FCHMOD
 			fchmod(fileno(fp), (S_IRUGO|S_IWUGO));
+#else
+#	ifdef HAVE_CHMOD
+			chmod(file, (S_IRUGO|S_IWUGO));
+#	endif /* HAVE_CHMOD */
+#endif /* HAVE_FCHMOD */
 			fclose(fp);
 		}
 	}
