@@ -3,35 +3,38 @@
  *  Module    : filter.c
  *  Author    : I. Lea
  *  Created   : 1992-12-28
- *  Updated   : 2019-02-18
+ *  Updated   : 2020-05-28
  *  Notes     : Filter articles. Kill & auto selection are supported.
  *
- * Copyright (c) 1991-2019 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -647,6 +650,10 @@ read_filter_file(
 				break;
 		}
 	}
+
+	if (comment) /* stray comment without scope */
+		(void) free_filter_comment(comment);
+
 	fclose(fp);
 
 	if (expired || (upgrade && upgrade->state == RC_UPGRADE))
@@ -1889,10 +1896,13 @@ filter_articles(
 
 	/*
 	 * loop through all arts applying global & local filtering rules
-	 *
-	 * TODO: allow iKeyAbort to stop filtering
 	 */
 	for (i = 0; (i < top_art) && !error; i++) {
+#ifdef HAVE_SELECT
+		if (wait_for_input())   /* allow abort */
+			break; /* to free the mem */
+#endif /* HAVE_SELECT */
+
 		arts[i].score = 0;
 
 		if (tinrc.kill_level == KILL_UNREAD && IS_READ(i)) /* skip only when the article is read */
@@ -2112,25 +2122,23 @@ filter_articles(
 						} else {
 #ifdef DEBUG
 							if (debug & DEBUG_FILTER) /* TODO: lang.c, _()? */
-								debug_print_file("FILTER", "Skipping xref filter");
+								debug_print_file("FILTER", "Skipping Xref filter");
 #endif /* DEBUG */
 							error = TRUE;
 							break;
 						}
 
-						if (ptr[j].xref != NULL) {
-							switch (test_regex(k, ptr[j].xref, ptr[j].icase, &regex_cache_xref[j])) {
-								case 1:
-									SET_FILTER(group, i, j);
-									break;
+						switch (test_regex(k, ptr[j].xref, ptr[j].icase, &regex_cache_xref[j])) {
+							case 1:
+								SET_FILTER(group, i, j);
+								break;
 
-								case -1:
-									error = TRUE;
-									break;
+							case -1:
+								error = TRUE;
+								break;
 
-								default:
-									break;
-							}
+							default:
+								break;
 						}
 						free(k);
 					}
@@ -2157,6 +2165,10 @@ filter_articles(
 				}
 			}
 		}
+		/*
+		 * if (i % (MODULO_COUNT_NUM * 20) == 0)
+		 *    show_progress("Filter", i, top_art);
+		 */
 	}
 
 	/*
@@ -2202,6 +2214,7 @@ filter_articles(
 			}
 		}
 	}
+
 	if (!cmd_line && !batch_mode)
 		clear_message();
 
