@@ -3,7 +3,7 @@
  *  Module    : getline.c
  *  Author    : Chris Thewalt & Iain Lea
  *  Created   : 1991-11-09
- *  Updated   : 2018-02-06
+ *  Updated   : 2020-06-01
  *  Notes     : emacs style line editing input package.
  *  Copyright : (c) Copyright 1991-99 by Chris Thewalt & Iain Lea
  *              Permission to use, copy, modify, and distribute this
@@ -47,7 +47,6 @@
 #else
 	static char gl_buf[BUF_SIZE];	/* input buffer */
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
-static int gl_init_done = 0;	/* -1 is terminal, 1 is batch */
 static const char *gl_prompt;	/* to save the prompt string */
 static int gl_width = 0;	/* net size available for input */
 static int gl_pos, gl_cnt = 0;	/* position and size of input */
@@ -117,7 +116,7 @@ tin_getline(
 
 	if (max_chars == 0) {
 		if (number_only)
-			gl_max = 6;
+			gl_max = 10;
 		else
 			gl_max = BUF_SIZE;
 	} else
@@ -513,18 +512,11 @@ void
 gl_redraw(
 	void)
 {
-	if (gl_init_done == -1) {	/* terminal */
-		my_fputc('\n', stdout);
-		my_fputs(gl_prompt, stdout);
-		gl_pos = 0;
-		gl_fixup(0, BUF_SIZE);
-	} else if (gl_init_done == 0) {	/* screen */
-		clear_message();
-		my_fputs(gl_prompt, stdout);
-		gl_pos = 0;
-		gl_fixup(0, BUF_SIZE);
-		cursoron();
-	}
+	clear_message();
+	my_fputs(gl_prompt, stdout);
+	gl_pos = 0;
+	gl_fixup(0, BUF_SIZE);
+	cursoron();
 }
 
 
