@@ -3,10 +3,10 @@
  *  Module    : init.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2019-08-20
+ *  Updated   : 2020-09-28
  *  Notes     :
  *
- * Copyright (c) 1991-2020 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -803,10 +803,10 @@ init_selfinfo(
 	if (!*overviewfmt_file)
 		joinpath(overviewfmt_file, sizeof(overviewfmt_file), libdir, OVERVIEW_FMT);
 	if (!*default_organization) {
-		char buf[LEN];
-
 		joinpath(tmp, sizeof(tmp), libdir, "organization");
 		if ((fp = fopen(tmp, "r")) != NULL) {
+			char buf[LEN];
+
 			if (fgets(buf, (int) sizeof(buf), fp) != NULL) {
 				ptr = strrchr(buf, '\n');
 				if (ptr != NULL)
@@ -912,7 +912,13 @@ init_selfinfo(
 		if (!fstat(fileno(fp), &sb)) {
 			if (sb.st_size == 0) {
 				fprintf(fp, "%s", _(txt_posted_info_file));
+#ifdef HAVE_FCHMOD
 				fchmod(fileno(fp), (mode_t) (S_IRUSR|S_IWUSR));
+#else
+#	ifdef HAVE_CHMOD
+				chmod(posted_info_file, (mode_t) (S_IRUSR|S_IWUSR));
+#	endif /* HAVE_CHMOD */
+#endif /* HAVE_FCHMOD */
 			}
 		}
 		fclose(fp);
