@@ -3,35 +3,38 @@
  *  Module    : page.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2019-02-15
+ *  Updated   : 2019-07-10
  *  Notes     :
  *
- * Copyright (c) 1991-2019 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote
- *    products derived from this software without specific prior written
- *    permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
- * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
- * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
- * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * 3. Neither the name of the copyright holder nor the names of its
+ *    contributors may be used to endorse or promote products derived from
+ *    this software without specific prior written permission.
+ *
+ * * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -1278,10 +1281,11 @@ invoke_metamail(
 		perror_message(_(txt_command_failed), ptr);
 		return;
 	}
-	if ((mime_fp = fdopen(fd_mime, "w"))) {
+	if ((mime_fp = fdopen(fd_mime, "w")))
 #else
-	if ((mime_fp = popen(ptr, "w"))) {
+	if ((mime_fp = popen(ptr, "w")))
 #endif /* DONT_HAVE_PIPING */
+	{
 		rewind(fp);
 		while (fgets(buf, (int) sizeof(buf), fp) != NULL)
 			fputs(buf, mime_fp);
@@ -1291,7 +1295,7 @@ invoke_metamail(
 		fseek(fp, offset, SEEK_SET);	/* goto old position */
 
 #ifdef DONT_HAVE_PIPING
-		snprintf(buf, sizeof(buf) -1, "%s %s", tinrc.metamail_prog, mimefile);
+		snprintf(buf, sizeof(buf) - 1, "%s %s", tinrc.metamail_prog, mimefile);
 		invoke_cmd(buf);
 		fclose(mime_fp);
 		unlink(mimefile);
@@ -1369,15 +1373,15 @@ draw_page_header(
 	if (right_len > cCOLS / 3 + 1)
 		right_len = cCOLS / 3 + 1;
 
+#	ifdef HAVE_COLOR
+	fcol(tinrc.col_head);
+#	endif /* HAVE_COLOR */
+
 	/*
 	 * first line
 	 */
 	cur_pos = 0;
 
-#	ifdef HAVE_COLOR
-	fcol(tinrc.col_head);
-#	endif /* HAVE_COLOR */
-
 	/* date */
 	if ((wtmp = char2wchar_t(buf)) != NULL) {
 		my_fputws(wtmp, stdout);
@@ -1437,10 +1441,6 @@ draw_page_header(
 	 */
 	cur_pos = 0;
 
-#	ifdef HAVE_COLOR
-	fcol(tinrc.col_head);
-#	endif /* HAVE_COLOR */
-
 	/* line count */
 	if (arts[this_resp].line_count < 0)
 		strcpy(buf, "?");
@@ -1483,6 +1483,8 @@ draw_page_header(
 	 * TODO: why do we fall back to arts[this_resp].subject if !note_h->subj?
 	 *       if !note_h->subj then the article just has no subject, no matter
 	 *       what the overview says.
+	 *
+	 *       add BiDi handling
 	 */
 	strncpy(buf, (note_h->subj ? note_h->subj : arts[this_resp].subject), line_len);
 	buf[line_len - 1] = '\0';
@@ -1545,6 +1547,8 @@ draw_page_header(
 	 * TODO: don't use arts[this_resp].name/arts[this_resp].from
 	 *       split up note_h->from and use that instead as it might
 	 *       be different _if_ the overviews are broken
+	 *
+	 *       add BiDi handling
 	 */
 	{
 		char *p = idna_decode(arts[this_resp].from);
@@ -1571,6 +1575,7 @@ draw_page_header(
 	 *
 	 * TODO: IDNA decoding, see also comment in
 	 *       cook.c:cook_article()
+	 *       add BiDi handling
 	 */
 	if (note_h->org) {
 		snprintf(buf, line_len, _(txt_at_s), note_h->org);
@@ -1601,15 +1606,15 @@ draw_page_header(
 	 */
 	right_len = MAX((strlen(_(txt_thread_x_of_n)) - 6 + 8), (strlen(_(txt_art_x_of_n)) - 6 + 8));
 
+#	ifdef HAVE_COLOR
+	fcol(tinrc.col_head);
+#	endif /* HAVE_COLOR */
+
 	/*
 	 * first line
 	 */
 	cur_pos = 0;
 
-#	ifdef HAVE_COLOR
-	fcol(tinrc.col_head);
-#	endif /* HAVE_COLOR */
-
 	/* date */
 	my_fputs(buf, stdout);
 	cur_pos += strlen(buf);
@@ -1660,10 +1665,6 @@ draw_page_header(
 	 */
 	cur_pos = 0;
 
-#	ifdef HAVE_COLOR
-	fcol(tinrc.col_head);
-#	endif /* HAVE_COLOR */
-
 	/* line count */
 	/* an accurate line count will appear in the footer anymay */
 	if (arts[this_resp].line_count < 0)
@@ -2624,7 +2625,8 @@ build_url_list(
 		/*
 		 * Line contains a URL, so read it in
 		 */
-		fseek(pgart.cooked, artline[i].offset, SEEK_SET);
+		if (fseek(pgart.cooked, artline[i].offset, SEEK_SET) == -1) /* skip on error */
+			continue;
 		if ((ptr = tin_fgets(pgart.cooked, FALSE)) == NULL)
 			continue;
 
