@@ -3,10 +3,10 @@
  *  Module    : rfc2046.c
  *  Author    : Jason Faultless <jason@altarstone.com>
  *  Created   : 2000-02-18
- *  Updated   : 2019-10-25
+ *  Updated   : 2020-12-17
  *  Notes     : RFC 2046 MIME article parsing
  *
- * Copyright (c) 2000-2020 Jason Faultless <jason@altarstone.com>
+ * Copyright (c) 2000-2021 Jason Faultless <jason@altarstone.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -153,7 +153,7 @@ boundary_cmp(
 	/* remove trailing whites as per RFC 2046 5.1.1 */
 	l = my_strdup(line);
 	e = l + len - 1;
-	while(e > l + blen + 1 && isspace(*e))
+	while (e > l + blen + 1 && isspace(*e))
 		*e-- = '\0';
 
 	len = strlen(l);
@@ -1250,8 +1250,11 @@ parse_multipart_article(
 
 			case M_HDR:
 				switch (bnd) {
-					case BOUND_START:	/* TODO: skip error message if not -DDEBUG? */
-						error_message(2, _(txt_error_mime_start));
+					case BOUND_START:
+#ifdef DEBUG
+						if (debug & DEBUG_MISC)
+							error_message(2, _(txt_error_mime_start));
+#endif /* DEBUG */
 						continue;
 
 					case BOUND_NONE:
@@ -1456,6 +1459,12 @@ parse_rfc2045_article(
 	if ((ret = parse_rfc822_headers(&artinfo->hdr, infile, artinfo->raw)) != 0)
 		goto error;
 
+	/* no article data returned, just a '.' after 220er response */
+	if (ret == 0 && artinfo->hdr.ext->offset == 0) {
+		ret = ART_UNAVAILABLE;
+		goto error;
+	}
+
 	/*
 	 * Is this a MIME article ?
 	 * We don't bother to parse all plain text articles
@@ -1465,8 +1474,10 @@ parse_rfc2045_article(
 			/* Strip off EOF condition if present */
 			if (ret & TIN_EOF) {
 				ret ^= TIN_EOF;
-				/* TODO: skip error message if not -DDEBUG? */
-				error_message(2, _(txt_error_mime_end), content_types[artinfo->hdr.ext->type], artinfo->hdr.ext->subtype);
+#ifdef DEBUG
+				if (debug & DEBUG_MISC)
+					error_message(2, _(txt_error_mime_end), content_types[artinfo->hdr.ext->type], artinfo->hdr.ext->subtype);
+#endif /* DEBUG */
 				if (ret != 0)
 					goto error;
 			} else
@@ -1566,7 +1577,7 @@ art_open(
 	progress_mesg = pmesg;
 	if (parse_rfc2045_article(fp, art->line_count, artinfo, show_progress_meter) != 0) {
 		progress_mesg = NULL;
-		return ART_ABORT;
+		return ((tin_errno == 0) ? ART_UNAVAILABLE : ART_ABORT);
 	}
 	progress_mesg = NULL;
 
